@@ -2,10 +2,77 @@ use strict;
 use warnings;
 
 package Data::Remember::POE;
+{
+  $Data::Remember::POE::VERSION = '0.140480';
+}
+# ABSTRACT: a brain for Data::Remember linked to the POE session heap
+
+use Data::Remember::Util 
+    init_brain  => { -as => '_init_brain' };
+
+
+sub new {
+    my $class  = shift;
+    my @config = @_;
+
+    return bless { config => \@config }, $class;
+}
+
+
+sub new_heap {
+    my $self = shift;
+
+    my @config = scalar(@_) ? @_ : @{ $self->{config} };
+
+    return _init_brain(@config);
+}
+
+
+sub remember {
+    my $self = shift;
+    my $que  = shift;
+    my $fact = shift;
+
+    return POE::Kernel->get_active_session->get_heap->remember($que, $fact); 
+}
+
+
+sub recall {
+    my $self = shift;
+    my $que  = shift;
+
+    return POE::Kernel->get_active_session->get_heap->recall($que);
+}
+
+
+sub forget {
+    my $self = shift;
+    my $que  = shift;
+
+    return POE::Kernel->get_active_session->get_heap->forget($que);
+}
+
+
+sub brain {
+    my $self = shift;
+
+    return POE::Kernel->get_active_session->get_heap;
+}
+
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
-Data::Remember::POE  a brain for Data::Remember linked to the session heap
+Data::Remember::POE - a brain for Data::Remember linked to the POE session heap
+
+=head1 VERSION
+
+version 0.140480
 
 =head1 SYNOPSIS
 
@@ -57,15 +124,6 @@ This means that it's possible to define two POE sessions that use L<Data::Rememb
 
 Creates a new object and tells the brain to use C<CONFIG> as the default heap configuration.
 
-=cut
-
-sub new {
-    my $class  = shift;
-    my @config = @_;
-
-    return bless { config => \@config }, $class;
-}
-
 =head2 new_heap [ CONFIG ]
 
 Creates a new brain object to be stored in a sessions heap established when L<POE::Session/create> is called. This new heap will be created according to the configuration from when L<Data::Remember> was used. For example,
@@ -83,82 +141,35 @@ You may also specify a C<CONFIG> argument, which will override the configuration
 
 This overrides whatever options were set during the use and uses L<Data::Remember::YAML> instead.
 
-=cut
-
-sub new_heap {
-    my $self = shift;
-
-    my @config = scalar(@_) ? @_ : @{ $self->{config} };
-
-    return Data::Remember::_init_brain(@config);
-}
-
 =head2 remember QUE, FACT
 
 Stores C<FACT> into C<QUE> for the brain in the current POE session.
 
-=cut
-
-sub remember {
-    my $self = shift;
-    my $que  = shift;
-    my $fact = shift;
-
-    return POE::Kernel->get_active_session->get_heap->remember($que, $fact); 
-}
-
 =head2 recall QUE
 
 Fetches the fact that has been stored in C<QUE> for the brain in the current POE session heap.
 
-=cut
-
-sub recall {
-    my $self = shift;
-    my $que  = shift;
-
-    return POE::Kernel->get_active_session->get_heap->recall($que);
-}
-
 =head2 forget QUE
 
 Deletes any fact that has been stored in C<QUE> for the brain in the current POE session heap.
 
-=cut
-
-sub forget {
-    my $self = shift;
-    my $que  = shift;
-
-    return POE::Kernel->get_active_session->get_heap->forget($que);
-}
-
 =head2 brain
 
 Returns the brain stored in the current session heap, in case you need to call any brain methods there.
 
-=cut
-
-sub brain {
-    my $self = shift;
-
-    return POE::Kernel->get_active_session->get_heap;
-}
-
 =head1 SEE ALSO
 
 L<Data::Remember>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 Boomer Consulting, Inc. All Rights Reserved.
+This software is copyright (c) 2014 by Qubling Software LLC.
 
-This program is free software and may be modified and distributed under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
